@@ -12,7 +12,8 @@
 #' \item{\code{get_metatab}}{\cr Retrieve list of meta-analytic tables.}
 #' \item{\code{get_ad}}{\cr Retrieve list of artifact-distribution objects or a summary table of artifact descriptive statistics.}
 #' \item{\code{get_plots}}{\cr Retrieve list of meta-analytic plots.}
-#' \item{\code{get_escalc}}{\cr Retrieve list of escalc objects (i.e., effect-size data).}
+#' \item{\code{get_escalc}}{\cr Retrieve list of escalc objects (i.e., effect-size data) for use with \pkg{metafor}.}
+#' \item{\code{get_metafor}}{\cr Alias for \code{get_escalc}.}
 #' \item{\code{get_followup}}{\cr Retrieve list of follow-up analyses.}
 #' \item{\code{get_leave1out}}{\cr Retrieve list of leave-one-out meta-analyses (special case of \code{get_followup}).}
 #' \item{\code{get_cumulative}}{\cr Retrieve list of cumulative meta-analyses (special case of \code{get_followup}).}
@@ -78,7 +79,7 @@
 
 #' @rdname get_stuff
 #' @export
-get_escalc <- function(ma_obj, analyses = "all", match = c("all", "any"), case_sensitive = TRUE, ...){
+get_metafor <- get_escalc <- function(ma_obj, analyses = "all", match = c("all", "any"), case_sensitive = TRUE, ...){
 
      ma_obj_filtered <- filter_ma(ma_obj = ma_obj, analyses = analyses, match = match, case_sensitive = case_sensitive, ...)
 
