@@ -7,7 +7,7 @@
 #' @param cor_data Square matrix (or vector of column names to match with \code{data}) containing correlations among variables.
 #' @param common_data Vector or matrix (or vector of column names to match with \code{data}) of data common to both X and Y variables (e.g., sample size, study-wise moderators).
 #' @param unique_data Vector or matrix (or vector of column names to match with \code{data}) of data unique to X and Y variables (e.g., mean, SD, reliability).
-#' @param diag_label Optional name to attrible to values extracted from the diagonal of the matrix (if NULL, no values are extracted from the diagonal).
+#' @param diag_label Optional name to attribute to values extracted from the diagonal of the matrix (if NULL, no values are extracted from the diagonal).
 #' @param lower_tri Logical scalar that identifies whether the correlations are in the lower triangle (\code{TRUE}) or in the upper triangle \code{FALSE} of the matrix.
 #' @param data Matrix, dataframe, or tibble containing study data (when present, column names of \code{data} will be matched to column names provided as other arguments).
 #'
@@ -56,12 +56,12 @@ reshape_mat2dat <- function(var_names, cor_data, common_data = NULL, unique_data
 
      if(!is.null(data)){
           data <- as_tibble(data)
-          var_names <- match_variables(call = call_full[[match("var_names", names(call_full))]], arg = var_names, data = data)
-          cor_data <- match_variables(call = call_full[[match("cor_data", names(call_full))]], arg = cor_data, data = data, as_array = TRUE)
+          var_names <- match_variables(call = call_full[[match("var_names", names(call_full))]], arg = var_names, arg_name = "var_names", data = data)
+          cor_data <- match_variables(call = call_full[[match("cor_data", names(call_full))]], arg = cor_data, arg_name = "cor_data", data = data, as_array = TRUE)
           if(deparse(substitute(common_data))[1] != "NULL")
-               common_data <- match_variables(call = call_full[[match("common_data",  names(call_full))]], arg = common_data, data = data, as_array = TRUE)
+               common_data <- match_variables(call = call_full[[match("common_data",  names(call_full))]], arg = common_data, arg_name = "common_data", data = data, as_array = TRUE)
           if(deparse(substitute(unique_data))[1] != "NULL")
-               unique_data <- match_variables(call = call_full[[match("unique_data",  names(call_full))]], arg = unique_data, data = data, as_array = TRUE)
+               unique_data <- match_variables(call = call_full[[match("unique_data",  names(call_full))]], arg = unique_data, arg_name = "unique_data", data = data, as_array = TRUE)
      }
      if(!is.null(dim(var_names))) var_names <- unlist(var_names)
      var_names <- as.character(var_names)
@@ -117,14 +117,15 @@ reshape_mat2dat <- function(var_names, cor_data, common_data = NULL, unique_data
      colnames(unique_data_x) <- paste0(colnames(unique_data_x), "_x")
      colnames(unique_data_y) <- paste0(colnames(unique_data_y), "_y")
 
-     cbind(cor_data_trans, common_data_out, unique_data_x, unique_data_y)
-
+     out <- cbind(cor_data_trans, common_data_out, unique_data_x, unique_data_y)
+     rownames(out) <- 1:nrow(out)
+     out
 }
 
 
 #' Reshape database from wide format to long format
 #'
-#' This function automates the process of converting a wide-format database (i.e,. a database in which intercorrelations between construct pairs define the columns, such that there are mutiple columns of correlations) to a long-format database (i.e., a database with just one column of correlations).
+#' This function automates the process of converting a wide-format database (i.e., a database in which intercorrelations between construct pairs define the columns, such that there are multiple columns of correlations) to a long-format database (i.e., a database with just one column of correlations).
 #' The meta-analysis functions in \pkg{psychmeta} work best with long-format databases, so this function can be a helpful addition to one's workflow when data are organized in a wide format.
 #'
 #' @param data Database of data for use in a meta-analysis in "wide" format.
@@ -155,7 +156,7 @@ reshape_mat2dat <- function(var_names, cor_data, common_data = NULL, unique_data
 #'                       c(mean = 2, sd = .25),
 #'                       rbind(value = c(1, 2, 3), weight = c(1, 2, 1))))
 #'
-#' ## Simultate with wide format
+#' ## Simulate with wide format
 #' data <- simulate_r_database(k = 10, n_params = n_params, rho_params = rho_params,
 #'                           rel_params = rel_params, sr_params = sr_params,
 #'                           sr_composite_params = sr_composite_params, wt_params = wt_params,
@@ -176,29 +177,43 @@ reshape_mat2dat <- function(var_names, cor_data, common_data = NULL, unique_data
 #' ## Reshape the data to "long" format
 #' reshape_wide2long(data = data, common_vars = common_vars, es_design = es_design,
 #'                            n_design = n_design, other_design = other_design)
-reshape_wide2long <- function(data, common_vars, es_design, n_design, other_design, es_name = "rxyi"){
+reshape_wide2long <- function(data, common_vars = NULL, es_design, n_design, other_design = NULL, es_name = "rxyi"){
+
+     if(!is.matrix(es_design)) stop("'es_design' must be a matrix", call. = FALSE)
 
      es_cnames <- colnames(es_design)
      es_rnames <- rownames(es_design)
-     other_rnames <- rownames(other_design)
 
      if(!all(es_cnames %in% es_rnames) | !all(es_rnames %in% es_cnames))
           stop("Rownames and column names of 'es_design' must contain the same elements", call. = FALSE)
-     if(!all(es_rnames %in% other_rnames))
-          stop("Variables represented in 'es_design' must be present in the rows of 'other_design'", call. = FALSE)
-     other_design <- other_design[es_rnames,]
+
+     if(!is.null(other_design)){
+          if(!is.matrix(other_design)) stop("'other_design' must be a matrix", call. = FALSE)
+          other_rnames <- rownames(other_design)
+          other_cnames <- colnames(other_design)
+          if(!all(es_rnames %in% other_rnames))
+               stop("Variables represented in 'es_design' must be present in the rows of 'other_design'", call. = FALSE)
+          .colnames <- colnames(other_design)
+          other_design <- as.matrix(other_design[es_rnames,])
+          colnames(other_design) <- .colnames
+     }else{
+          other_rnames <- NULL
+          other_cnames <- NULL
+     }
 
      if(length(n_design) == 1){
-          n_scalar <- n_design
+          n_scalar <- c(n_design)
           n_design <- es_design
           n_design[lower.tri(n_design)] <- n_scalar
      }else{
+          if(!is.matrix(n_design)) stop("'n_design' must be a matrix if it has more than 1 element", call. = FALSE)
           n_cnames <- colnames(n_design)
           n_rnames <- rownames(n_design)
           if(!all(es_cnames %in% es_rnames) | !all(es_rnames %in% es_cnames))
                stop("Rownames and column names of 'es_design' must contain the same elements", call. = FALSE)
-          if(!all(es_rnames %in% other_rnames))
-               stop("Variables represented in 'n_design' must be identical to the variables in 'es_design'", call. = FALSE)
+          if(!is.null(other_rnames))
+               if(!all(es_rnames %in% other_rnames))
+                    stop("Variables represented in 'n_design' must be identical to the variables in 'es_design'", call. = FALSE)
      }
 
      unique_refs <- levels(factor(c(es_design, other_design)))
@@ -208,13 +223,13 @@ reshape_wide2long <- function(data, common_vars, es_design, n_design, other_desi
 
      var_names <- es_cnames
 
-     new_data <- data.frame(matrix(NA, 0, length(common_vars) + 4 + 2 * ncol(other_design)))
+     new_data <- data.frame(matrix(NA, 0, length(common_vars) + 4 + 2 * length(other_cnames)))
      colnames(new_data) <- c(common_vars, "n", es_name, "x_name", "y_name",
-                             paste0(colnames(other_design), "_x"),
-                             paste0(colnames(other_design), "_y"))
+                             if(length(other_cnames) > 0){paste0(other_cnames, "_x")}else{NULL},
+                             if(length(other_cnames) > 0){paste0(other_cnames, "_y")}else{NULL})
      colnames_ij <- c(common_vars, "n", es_name,
-                      paste0(colnames(other_design), "_x"),
-                      paste0(colnames(other_design), "_y"))
+                      if(length(other_cnames) > 0){paste0(other_cnames, "_x")}else{NULL},
+                      if(length(other_cnames) > 0){paste0(other_cnames, "_y")}else{NULL})
 
      es_data <- n_data <- other_data <- NULL
      for(i in 1:length(var_names)){
@@ -241,12 +256,14 @@ reshape_wide2long <- function(data, common_vars, es_design, n_design, other_desi
 #' The \code{reshape_vec2mat} function facilitates the creation of square correlation/covariance matrices from scalars or vectors of variances/covariances.
 #' It allows the user to supply a vector of covariances that make up the lower triangle of a matrix, determines the order of the matrix necessary to hold those covariances, and constructs a matrix accordingly.
 #'
-#' @param cov Scalar or vector of covariance information to include the off-diagonal positions of the matrix (default value is zero).
-#' If a vector, the elements must be provided in the order associated with concatenated column vectors of the lower triangle of the desired matrix,
-#' which is the order or elements that would occur if the lower triangle of the desired matrix were extracted with the following R function: x[lower.tri(x)].
+#' @param cov Scalar or vector of covariance information to include the lower-triangle positions of the matrix (default value is zero).
+#' If a vector, the elements must be provided in the order associated with concatenated column (\code{by_row = FALSE; default}) or row (\code{by_row = TRUE}) vectors of the lower triangle of the desired matrix.
+#' If variances are included in these values, set the \code{diag} argument to \code{TRUE}.
 #' @param var Scalar or vector of variance information to include the diagonal positions of the matrix (default value is 1).
 #' @param order If cov and var are scalars, this argument determines the number of variables to create in the output matrix.
 #' @param var_names Optional vector of variable names.
+#' @param by_row Logical scalar indicating whether \code{cov} values should fill the lower triangle by row (\code{TRUE}) or by column (\code{FALSE}; default).
+#' @param diag Logical scalar indicating whether \code{cov} values include variances (\code{FALSE} by default; if \code{TRUE}, the variance values supplied with the \code{cov} argument will supersede the \code{var} argument).
 #'
 #' @return A variance-covariance matrix
 #' @export
@@ -257,7 +274,7 @@ reshape_wide2long <- function(data, common_vars, es_design, n_design, other_desi
 #' reshape_vec2mat(cov = c(.3, .2, .4), var_names = c("x", "y", "z"))
 #'
 #' ## Specify scalar values to repeat for the covariances and variances
-#' c(cov = .3, var = 2, order = 3)
+#' reshape_vec2mat(cov = .3, var = 2, order = 3)
 #'
 #' ## Give a vector of variances to create a diagonal matrix
 #' reshape_vec2mat(var = 1:5)
@@ -270,12 +287,16 @@ reshape_wide2long <- function(data, common_vars, es_design, n_design, other_desi
 #'
 #' ## A quick way to make a 2x2 matrix for bivariate correlations
 #' reshape_vec2mat(cov = .2)
-reshape_vec2mat <- function(cov = NULL, var = NULL, order = NULL, var_names = NULL){
+reshape_vec2mat <- function(cov = NULL, var = NULL, order = NULL, var_names = NULL, by_row = FALSE, diag = FALSE){
      if(is.null(var) & is.null(cov) & is.null(order))
           stop("cov, var, and/or order must be specified")
      if(is.null(order)){
           if(!is.null(cov)){
-               order <- sqrt(length(cov) * 2 + .5 * (1 + sqrt(1 + 4 * length(cov) * 2)))
+               if(diag){
+                    order <- .5 * (sqrt(8 * length(cov) + 1) - 1)
+               }else{
+                    order <- sqrt(length(cov) * 2 + .5 * (1 + sqrt(1 + 4 * length(cov) * 2)))
+               }
                if(order != round(order)) stop("length of cov does not correspond to a valid number of lower-triangle correlations", call. = FALSE)
           }
           if(!is.null(var))
@@ -283,21 +304,34 @@ reshape_vec2mat <- function(cov = NULL, var = NULL, order = NULL, var_names = NU
      }
      if(is.null(var))
           var <- rep(1, order)
-     if(is.null(cov))
-          cov <- 0
+
+     if(length(cov) > 1 & diag)
+          var <- rep(0, order)
+     if(length(cov) == 1)
+          cov <- rep(cov, order * (order - 1) / 2)
      if(length(var) > 1)
           if(length(var) != order)
                stop("order does not match number of diagonal elements")
      mat <- diag(var / 2,  order)
-     if(length(cov) > 1)
-          if(sum(lower.tri(mat)) != length(cov))
-               stop("length of cov does not match elements in lower triangle")
-     mat[lower.tri(mat)] <- cov
+
+     if(length(cov) > 0){
+          if(by_row){
+               if(sum(lower.tri(mat, diag = diag)) != length(cov))
+                    stop("length of cov does not match elements in lower triangle")
+               mat[upper.tri(mat, diag = diag)] <- cov
+          }else{
+               if(sum(lower.tri(mat, diag = diag)) != length(cov))
+                    stop("length of cov does not match elements in lower triangle")
+               mat[lower.tri(mat, diag = diag)] <- cov
+          }
+          if(diag) diag(mat) <- diag(mat) / 2
+     }
+
      mat <- mat + t(mat)
+
      if(is.null(var_names))
           var_names <- paste("Var", 1:ncol(mat), sep = "")
      dimnames(mat) <- list(var_names, var_names)
      mat
 }
 
-
